@@ -6,9 +6,9 @@ Type annotations for kinesisanalyticsv2 service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kinesisanalyticsv2.literals import ApplicationRestoreTypeType
+    from mypy_boto3_kinesisanalyticsv2.literals import ApplicationModeType
 
-    data: ApplicationRestoreTypeType = "RESTORE_FROM_CUSTOM_SNAPSHOT"
+    data: ApplicationModeType = "INTERACTIVE"
     ```
 """
 import sys
@@ -20,8 +20,10 @@ else:
 
 
 __all__ = (
+    "ApplicationModeType",
     "ApplicationRestoreTypeType",
     "ApplicationStatusType",
+    "ArtifactTypeType",
     "CodeContentTypeType",
     "ConfigurationTypeType",
     "InputStartingPositionType",
@@ -36,6 +38,7 @@ __all__ = (
 )
 
 
+ApplicationModeType = Literal["INTERACTIVE", "STREAMING"]
 ApplicationRestoreTypeType = Literal[
     "RESTORE_FROM_CUSTOM_SNAPSHOT", "RESTORE_FROM_LATEST_SNAPSHOT", "SKIP_RESTORE_FROM_SNAPSHOT"
 ]
@@ -52,6 +55,7 @@ ApplicationStatusType = Literal[
     "STOPPING",
     "UPDATING",
 ]
+ArtifactTypeType = Literal["DEPENDENCY_JAR", "UDF"]
 CodeContentTypeType = Literal["PLAINTEXT", "ZIPFILE"]
 ConfigurationTypeType = Literal["CUSTOM", "DEFAULT"]
 InputStartingPositionType = Literal["LAST_STOPPED_POINT", "NOW", "TRIM_HORIZON"]
@@ -60,6 +64,8 @@ ListApplicationsPaginatorName = Literal["list_applications"]
 LogLevelType = Literal["DEBUG", "ERROR", "INFO", "WARN"]
 MetricsLevelType = Literal["APPLICATION", "OPERATOR", "PARALLELISM", "TASK"]
 RecordFormatTypeType = Literal["CSV", "JSON"]
-RuntimeEnvironmentType = Literal["FLINK-1_11", "FLINK-1_6", "FLINK-1_8", "SQL-1_0"]
+RuntimeEnvironmentType = Literal[
+    "FLINK-1_11", "FLINK-1_6", "FLINK-1_8", "SQL-1_0", "ZEPPELIN-FLINK-1_0"
+]
 SnapshotStatusType = Literal["CREATING", "DELETING", "FAILED", "READY"]
-UrlTypeType = Literal["FLINK_DASHBOARD_URL"]
+UrlTypeType = Literal["FLINK_DASHBOARD_URL", "ZEPPELIN_UI_URL"]
